/*
  ==============================================================================

    This file contains the basic framework code for a JUCE plugin editor.

  ==============================================================================
*/

#pragma once

#include <JuceHeader.h>
#include "PluginProcessor.h"

class BorderlessButtonLookAndFeel : public juce::LookAndFeel_V4
{
public:
    void drawButtonBackground(juce::Graphics& g,
        juce::Button& button,
        const juce::Colour& backgroundColour,
        bool isMouseOverButton,
        bool isButtonDown) override
    {
        // Do nothing, or add a transparent fill if needed
    }

    void drawButtonText(juce::Graphics& g, juce::TextButton& button,
        bool /*isMouseOverButton*/, bool /*isButtonDown*/) override
    {
        // Optional: hide text too
    }
};

//==============================================================================
/**
*/
class LeiwandizerAudioProcessorEditor  : public juce::AudioProcessorEditor
{
public:
    LeiwandizerAudioProcessorEditor (LeiwandizerAudioProcessor&);
    ~LeiwandizerAudioProcessorEditor() override;

    //==============================================================================
    void paint (juce::Graphics&) override;
    void resized() override;

private:
    // This reference is provided as a quick way for your editor to
    // access the processor object that created it.
    LeiwandizerAudioProcessor& audioProcessor;

    juce::Image backgroundOn;
    juce::Image backgroundOff;
    juce::TextButton btLeiwand;
    BorderlessButtonLookAndFeel borderlessLook;

    JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (LeiwandizerAudioProcessorEditor)
};
